==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/Input/flac/translations/flac_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="51"/>
        <source>FLAC Plugin</source>
        <translation>FLAC Module</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="53"/>
        <source>FLAC Files</source>
        <translation>FLAC Bestanden</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="183"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Over de FLAC Audio Module</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="184"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>FLAC Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="185"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Length</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Sample rate</source>
        <translation>Sample frequentie</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Hz</source>
        <translation>Hz</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="84"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>kbps</source>
        <translation>kbps</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="87"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/Input/flac/translations/flac_plugin_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="nl">
<context>
    <name>DecoderFLACFactory</name>
    <message>
        <location filename="../decoderflacfactory.cpp" line="57"/>
        <source>FLAC Plugin</source>
        <translation>FLAC Module</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="59"/>
        <source>FLAC Files</source>
        <translation>FLAC Bestanden</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="187"/>
        <source>About FLAC Audio Plugin</source>
        <translation>Over de FLAC Audio Module</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="188"/>
        <source>Qmmp FLAC Audio Plugin</source>
        <translation>FLAC Audio Module voor Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderflacfactory.cpp" line="189"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Auteur: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>FLACMetaDataModel</name>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="80"/>
        <source>Length</source>
        <translation>Duur</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Sample rate</source>
        <translation>Sample frequentie</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="81"/>
        <source>Hz</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="82"/>
        <source>Channels</source>
        <translation>Kanalen</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>Bitrate</source>
        <translation>Bitsnelheid</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="83"/>
        <source>kbps</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>File size</source>
        <translation>Bestandsgrootte</translation>
    </message>
    <message>
        <location filename="../flacmetadatamodel.cpp" line="85"/>
        <source>KB</source>
        <translation></translation>
    </message>
</context>
</TS>
